Skip to contents

Removes cached packages and archives from the condathis Conda root. Also removes files from the package cache directory returned by tools::R_user_dir(package = "condathis", which = "cache").

Usage

clean_cache(verbose = c("output", "silent", "cmd", "spinner", "full"))

Arguments

verbose

Character string controlling console output. Supported values are "output", "silent", "cmd", "spinner", and "full". Defaults to "output".

Value

A process result list (from processx::run()) with command output, error output, exit status, and timeout information.

Details

Package files still referenced by existing environments may not be removed. To maximize cleanup, remove environments first with list_envs() and remove_env().

Examples

if (FALSE) { # \dontrun{
condathis::with_sandbox_dir({
  clean_cache(verbose = "output")
})
} # }