Returns the data directory used by condathis, creating it when needed.
The base path follows the platform-specific user data directory rules used
by tools::R_user_dir().
Details
On macOS, condathis uses a path without spaces when possible because
micromamba run can fail on paths that contain spaces.
Examples
condathis::with_sandbox_dir({
print(condathis::get_install_dir())
#> /home/username/.local/share/condathis
})
#> /tmp/RtmpPvpOT3/tmp-data192d41ec9f07/R/condathis