This function returns the file path to the micromamba executable managed
by the condathis package. The path is determined based on the system's
operating system and architecture.
Value
A character string representing the full path to the micromamba
executable.
The path differs depending on the operating system:
Windows:
<install_dir>/micromamba/Library/bin/micromamba.exeOther OS (e.g., Linux, macOS):
<install_dir>/micromamba/bin/micromamba
Examples
condathis::with_sandbox_dir({
# Retrieve the path to where micromamba executable is searched
micromamba_path <- condathis::micromamba_bin_path()
print(micromamba_path)
})
#> /tmp/RtmpxLPxPN/tmp-data1d2f6235b9f0/R/condathis/micromamba/bin/micromamba